@@ -4,11 +4,15 @@ var group__gfx__func__draw =
     [ "af_draw_image", "group__gfx__func__draw.htm#ga6d43e196ca2748ca0b185e07db0be031", null ],
     [ "af_draw_plot", "group__gfx__func__draw.htm#gada090c398764cbe1475bdb1a1e31b85a", null ],
     [ "af_draw_plot3", "group__gfx__func__draw.htm#gab7a96f606051867f0734aaacedc1e275", null ],
+    [ "af_draw_scatter", "group__gfx__func__draw.htm#ga2ef3c95d1a0ce0ed4fe003ed53808ca2", null ],
+    [ "af_draw_scatter3", "group__gfx__func__draw.htm#ga764410fbdf0cd60c7044c77e36fb2577", null ],
     [ "af_draw_surface", "group__gfx__func__draw.htm#gaaee14e457272b2cd1bd4ed1228370229", null ],
     [ "hist", "group__gfx__func__draw.htm#gafd7d94aa8f5fd37fee0662a4906a38d7", null ],
     [ "image", "group__gfx__func__draw.htm#gaed174450be6db4dfa5ef65b7baccbe57", null ],
     [ "plot", "group__gfx__func__draw.htm#ga8e01736df3d805a5488c609e2573818b", null ],
     [ "plot3", "group__gfx__func__draw.htm#ga8e04ec129034e9fe769f3e6b14cd087f", null ],
-    [ "surface", "group__gfx__func__draw.htm#ga5bc913558053b79956c9d2200471565a", null ],
-    [ "surface", "group__gfx__func__draw.htm#ga392b0bb3ae1da66d0fdfb1ef538943e6", null ]
+    [ "scatter", "group__gfx__func__draw.htm#ga73406db589e5090c051baae0af175df9", null ],
+    [ "scatter3", "group__gfx__func__draw.htm#ga3bbfbe1b60741a259d2146b3ab50ace3", null ],
+    [ "surface", "group__gfx__func__draw.htm#ga1cdb8c3205d70d8feaddd8c30245393f", null ],
+    [ "surface", "group__gfx__func__draw.htm#ga2d09aa253b391ce82104352b743bb18c", null ]
 ];
\ No newline at end of file
